@@ -1305,7 +1305,7 @@ setup_invisible_texts (GooCanvasItem *root)
 
 
 static void
-plant_flower (GooCanvasItem *root, double x, double y, GooCanvasAnchorType anchor)
+plant_flower (GooCanvasItem *root, double x, double y, GooCanvasAnchorType anchor, gdouble opacity)
 {
   cairo_pattern_t *pattern;
   cairo_surface_t *surface;
@@ -1324,6 +1324,7 @@ plant_flower (GooCanvasItem *root, double x, double y, GooCanvasAnchorType ancho
 			       "width", w * 1.5,
 			       "height", h * 2,
 				"scale-to-fit", TRUE,
+				"alpha", opacity,
 			       NULL);
   cairo_pattern_destroy (pattern);
   setup_item_signals (image);
@@ -1352,10 +1353,10 @@ setup_images (GooCanvasItem *root)
   else
     g_warning ("Could not find the toroid.png sample file");
 
-  plant_flower (root,  20.0, 170.0, GOO_CANVAS_ANCHOR_NW);
-  plant_flower (root, 180.0, 170.0, GOO_CANVAS_ANCHOR_NE);
-  plant_flower (root,  20.0, 280.0, GOO_CANVAS_ANCHOR_SW);
-  plant_flower (root, 180.0, 280.0, GOO_CANVAS_ANCHOR_SE);
+  plant_flower (root,  20.0, 170.0, GOO_CANVAS_ANCHOR_NW, 0.3);
+  plant_flower (root, 180.0, 170.0, GOO_CANVAS_ANCHOR_NE, 0.5);
+  plant_flower (root,  20.0, 280.0, GOO_CANVAS_ANCHOR_SW, 0.7);
+  plant_flower (root, 180.0, 280.0, GOO_CANVAS_ANCHOR_SE, 1.0);
 }
 
 
@@ -1622,7 +1623,6 @@ main (int argc, char *argv[])
 {
   GtkWidget *window;
 
-  gtk_set_locale ();
   gtk_init (&argc, &argv);
 
   window = create_window ();
