@@ -79,7 +79,8 @@ enum {
   PROP_DESCRIPTION,
   PROP_CAN_FOCUS,
   PROP_CLIP_PATH,
-  PROP_CLIP_FILL_RULE
+  PROP_CLIP_FILL_RULE,
+  PROP_TOOLTIP
 };
 
 static gboolean accessibility_enabled = FALSE;
@@ -287,6 +288,9 @@ goo_canvas_item_simple_install_common_properties (GObjectClass *gobject_class)
   g_object_class_override_property (gobject_class, PROP_CAN_FOCUS,
 				    "can-focus");
 
+  g_object_class_override_property (gobject_class, PROP_TOOLTIP,
+				    "tooltip");
+
   /**
    * GooCanvasItemSimple:clip-path
    *
@@ -545,6 +549,9 @@ goo_canvas_item_simple_get_common_property (GObject                 *object,
     case PROP_CLIP_FILL_RULE:
       g_value_set_enum (value, simple_data->clip_fill_rule);
       break;
+    case PROP_TOOLTIP:
+      g_value_set_string (value, simple_data->tooltip);
+      break;
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
       break;
@@ -596,7 +603,7 @@ goo_canvas_item_simple_set_common_property (GObject                 *object,
   gboolean recompute_bounds = FALSE;
   cairo_matrix_t *transform;
   GValue tmpval = { 0 };
-  const char *font_name;
+  const char *font_name, *path_data;
   PangoFontDescription *font_desc = NULL;
 
   /* See if we need to create our own style. */
@@ -727,13 +734,20 @@ goo_canvas_item_simple_set_common_property (GObject                 *object,
     case PROP_CLIP_PATH:
       if (simple_data->clip_path_commands)
 	g_array_free (simple_data->clip_path_commands, TRUE);
-      simple_data->clip_path_commands = goo_canvas_parse_path_data (g_value_get_string (value));
+      path_data = g_value_get_string (value);
+      if (path_data)
+	simple_data->clip_path_commands = goo_canvas_parse_path_data (path_data);
+      else
+	simple_data->clip_path_commands = NULL;
       recompute_bounds = TRUE;
       break;
     case PROP_CLIP_FILL_RULE:
       simple_data->clip_fill_rule = g_value_get_enum (value);
       recompute_bounds = TRUE;
       break;
+    case PROP_TOOLTIP:
+      simple_data->tooltip = g_value_dup_string (value);
+      break;
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
       break;
@@ -1486,6 +1500,26 @@ goo_canvas_item_simple_set_model_internal    (GooCanvasItem      *item,
 }
 
 
+static gboolean
+goo_canvas_item_simple_query_tooltip (GooCanvasItem  *item,
+				      gdouble         x,
+				      gdouble         y,
+				      gboolean        keyboard_tip,
+				      GtkTooltip     *tooltip)
+{
+  GooCanvasItemSimple *simple = (GooCanvasItemSimple*) item;
+  GooCanvasItemSimpleData *simple_data = simple->simple_data;
+
+  if (simple_data->tooltip)
+    {
+      gtk_tooltip_set_markup (tooltip, simple_data->tooltip);
+      return TRUE;
+    }
+
+  return FALSE;
+}
+
+
 static void
 canvas_item_interface_init (GooCanvasItemIface *iface)
 {
@@ -1511,6 +1545,8 @@ canvas_item_interface_init (GooCanvasItemIface *iface)
 
   iface->get_model          = goo_canvas_item_simple_get_model;
   iface->set_model          = goo_canvas_item_simple_set_model_internal;
+
+  iface->query_tooltip	    = goo_canvas_item_simple_query_tooltip;
 }
 
 
@@ -1638,7 +1674,8 @@ goo_canvas_item_simple_get_path_bounds (GooCanvasItemSimple *item,
  * This function is intended to be used by subclasses of #GooCanvasItemSimple,
  * typically in their update() or get_requested_area() methods.
  *
- * It converts the item's bounds to a bounding box in device space.
+ * It converts the item's bounds to a bounding box in the canvas (device)
+ * coordinate space.
  **/
 void
 goo_canvas_item_simple_user_bounds_to_device (GooCanvasItemSimple *item,
@@ -1820,12 +1857,18 @@ goo_canvas_item_simple_get_line_width (GooCanvasItemSimple   *item)
  * item models. It can also be used as the base class for new custom canvas
  * item models.
  *
+ * <note><para>
+ * 	The Model/View canvas feature may be removed in a future version of
+ * 	GooCanvas.
+ * </para></note>
+ * 
  * It provides default implementations for many of the #GooCanvasItemModel
  * methods.
  *
  * Subclasses of #GooCanvasItemModelSimple only need to implement the
  * create_item() method of the #GooCanvasItemModel interface, to create
  * the default canvas item to view the item model.
+ *
  */
 
 
